//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-imaging-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using System.Numerics;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Imaging;
using GrapeCity.Documents.Svg;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;
using DsImagingWeb.Demos.Common;

namespace DsImagingWeb.Demos
{
    // This sample shows how to render an SVGZ (compressed SVG) image.
    // The SVG art used in this sample is from https://freesvg.org/.
    public class RenderSvgz
    {
        public GcBitmap GenerateImage(Size pixelSize, float dpi, bool opaque, string[] sampleParams = null)
        {
            var svgPath = Path.Combine("Resources", "SvgMisc", "Smiling-Girl.svgz");
            using var svg = GcSvgDocument.FromSvgz(File.ReadAllBytes(svgPath));

            // Render the SVG image and a border around it:
            var bmp = new GcBitmap(pixelSize.Width, pixelSize.Height, opaque, dpi, dpi);
            using var g = bmp.CreateGraphics(Color.White);
            var pt = new PointF(dpi, dpi);
            g.DrawSvg(svg, pt);
            var sz = svg.GetIntrinsicSize(SvgLengthUnits.Pixels);
            g.DrawRectangle(new RectangleF(pt, sz), Color.MediumPurple);

            // Done:
            return bmp;
        }
    }
}
